==> org-lsst-ccs-subsystem-fcs-buses-1.3.2-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/config/SingleFilterTestConfig.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.singlefiltertest.config;

import java.io.Serializable;

/**
 *
 * @author turri
 */
public class SingleFilterTestConfig implements Serializable {
    
    private ClampConfig clampXminusConfig, clampXplusConfig;
    private ActuatorConfig clampActuatorXminus, clampActuatorXplus;
    private ActuatorConfig latchActuatorXminus, latchActuatorXplus;
    

    public SingleFilterTestConfig(ClampConfig clampXminusConfig, ClampConfig clampXplusConfig, 
            ActuatorConfig clampActuatorXminus, ActuatorConfig clampActuatorXplus,
            ActuatorConfig latchActuatorXminus, ActuatorConfig latchActuatorXplus) {
        this.clampXminusConfig = clampXminusConfig;
        this.clampXplusConfig = clampXplusConfig;
        this.clampActuatorXminus = clampActuatorXminus;
        this.clampActuatorXplus = clampActuatorXplus;
        this.latchActuatorXminus = latchActuatorXminus;
        this.latchActuatorXplus = latchActuatorXplus;
    }

    public ClampConfig getClampXminusConfig() {
        return clampXminusConfig;
    }

    public ClampConfig getClampXplusConfig() {
        return clampXplusConfig;
    }

    public ActuatorConfig getClampActuatorXminus() {
        return clampActuatorXminus;
    }

    public void setClampActuatorXminus(ActuatorConfig clampActuatorXminus) {
        this.clampActuatorXminus = clampActuatorXminus;
    }

    public ActuatorConfig getClampActuatorXplus() {
        return clampActuatorXplus;
    }

    public void setClampActuatorXplus(ActuatorConfig clampActuatorXplus) {
        this.clampActuatorXplus = clampActuatorXplus;
    }
    
    public ActuatorConfig getLatchActuatorXminus() {
        return latchActuatorXminus;
    }

    public void setLatchActuatorXminus(ActuatorConfig latchActuatorXminus) {
        this.latchActuatorXminus = latchActuatorXminus;
    }

    public ActuatorConfig getLatchActuatorXplus() {
        return latchActuatorXplus;
    }

    public void setLatchActuatorXplus(ActuatorConfig latchActuatorXplus) {
        this.latchActuatorXplus = latchActuatorXplus;
    }
    
}

==> org-lsst-ccs-subsystem-fcs-buses-1.4.6-sources.jar: org/lsst/ccs/subsystems/fcs/singlefiltertest/config/SingleFilterTestConfig.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.singlefiltertest.config;

import java.io.Serializable;

/**
 * Creates an object to update the GUI.
 * @author turri
 */
public class SingleFilterTestConfig implements Serializable {
    
    private final boolean realHardware;
    private final ClampConfig clampXminusConfig, clampXplusConfig;
    private ActuatorConfig clampActuatorXminus, clampActuatorXplus;
    private ActuatorConfig latchActuatorXminus, latchActuatorXplus;
    

    public SingleFilterTestConfig(boolean controlRealHardware, ClampConfig clampXminusConfig, ClampConfig clampXplusConfig, 
            ActuatorConfig clampActuatorXminus, ActuatorConfig clampActuatorXplus,
            ActuatorConfig latchActuatorXminus, ActuatorConfig latchActuatorXplus) {
        this.realHardware = controlRealHardware;
        this.clampXminusConfig = clampXminusConfig;
        this.clampXplusConfig = clampXplusConfig;
        this.clampActuatorXminus = clampActuatorXminus;
        this.clampActuatorXplus = clampActuatorXplus;
        this.latchActuatorXminus = latchActuatorXminus;
        this.latchActuatorXplus = latchActuatorXplus;
    }

    public boolean isRealHardware() {
        return realHardware;
    }

    public ClampConfig getClampXminusConfig() {
        return clampXminusConfig;
    }

    public ClampConfig getClampXplusConfig() {
        return clampXplusConfig;
    }

    public ActuatorConfig getClampActuatorXminus() {
        return clampActuatorXminus;
    }

    public void setClampActuatorXminus(ActuatorConfig clampActuatorXminus) {
        this.clampActuatorXminus = clampActuatorXminus;
    }

    public ActuatorConfig getClampActuatorXplus() {
        return clampActuatorXplus;
    }

    public void setClampActuatorXplus(ActuatorConfig clampActuatorXplus) {
        this.clampActuatorXplus = clampActuatorXplus;
    }
    
    public ActuatorConfig getLatchActuatorXminus() {
        return latchActuatorXminus;
    }

    public void setLatchActuatorXminus(ActuatorConfig latchActuatorXminus) {
        this.latchActuatorXminus = latchActuatorXminus;
    }

    public ActuatorConfig getLatchActuatorXplus() {
        return latchActuatorXplus;
    }

    public void setLatchActuatorXplus(ActuatorConfig latchActuatorXplus) {
        this.latchActuatorXplus = latchActuatorXplus;
    }
    
}
